import React from "react";

import {
  XYPlot,
  // VerticalGridLines,
  HorizontalGridLines,
  XAxis,
  YAxis,
  LineMarkSeries,
  Hint
} from "react-vis";
import "react-vis/dist/style.css";
import { padStart } from "../../utils/Formater";

class PriceHistoryChart extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      priceHistory: {
        "1549891200": 200,
        "1552262400": 205,
        "1553212800": 208,
        "1558137600": 310,
        "1561161600": 390,
        "1562747189": 521
      },
      priceForecast: {
        "1565395200": 620,
        "1568073600": 735
      },
      start: null,
      end: null,
      datapoint: null,
      containerWidth: 800
    };
  }

  // componentDidMount() {
  //   window.addEventListener("resize", this.onResize.bind(this));
  // }
  // componentWillUnmount() {
  //   window.removeEventListener("resize", this.onResize.bind(this));
  // }

  // onResize() {
  //   console.log("RESIZE", this.plotContainer.clientWidth);
  //   this.setState({ containerWidth: this.plotContainer.clientWidth });
  // }

  // showHint(datapoint, event) {
  //   this.setValue({ datapoint });
  // }

  render() {
    const {
      priceHistory,
      priceForecast,
      // start,
      // end,
      datapoint,
      containerWidth
    } = this.state;

    const historySeriesData = parseChartData(priceHistory);
    const forecastSeriesData = parseChartData(priceForecast);
    forecastSeriesData.unshift(historySeriesData[historySeriesData.length - 1]);
    return (
      <div className="flex-1" ref={el => (this.plotContainer = el)}>
        <XYPlot width={containerWidth} height={300}>
          {/* <VerticalGridLines /> */}
          <HorizontalGridLines />
          <XAxis
            tickTotal={8}
            tickValues={[2, 3, 4, 5, 6, 7, 8, 9].map(v =>
              new Date(`2019-${padStart(v, 2, "0")}-01`).getTime()
            )}
            tickFormat={v => month(v)}
          />
          <YAxis />
          <LineMarkSeries
            className="linemark-series-example"
            style={{
              strokeWidth: "2px"
            }}
            strokeDasharray={[5, 5]}
            lineStyle={{ stroke: "grey" }}
            markStyle={{ stroke: "grey" }}
            data={forecastSeriesData}
            onValueMouseOver={(datapoint, event) => {
              this.setState({ datapoint });
            }}
            onValueMouseOut={() => {
              this.setState({ datapoint: null });
            }}
          />
          <LineMarkSeries
            className="linemark-series-example"
            style={{
              strokeWidth: "3px"
            }}
            lineStyle={{ stroke: "red" }}
            markStyle={{ stroke: "blue" }}
            data={historySeriesData}
            onValueMouseOver={(datapoint, event) => {
              this.setState({ datapoint });
            }}
            onValueMouseOut={() => {
              this.setState({ datapoint: null });
            }}
          />
          {datapoint && (
            <Hint
              value={datapoint}
              format={datapoint => [
                {
                  title: day(datapoint.x),
                  value: "$ " + (datapoint.y * 1).toFixed(2)
                }
              ]}
            />
          )}
        </XYPlot>
      </div>
    );
  }
}

export default PriceHistoryChart;

const parseChartData = (data = {}, start, end) => {
  return data.toArray((val, key) => ({ x: key * 1000, y: val / 100 }));
};

const monthShortNames = [
  "Jan",
  "Feb",
  "Mar",
  "Apr",
  "May",
  "Jun",
  "Jul",
  "Aug",
  "Sep",
  "Oct",
  "Nov",
  "Dec"
];
const month = time => {
  const date = new Date(time);
  return monthShortNames[date.getMonth()] + ", " + date.getFullYear();
};
const day = time => {
  const date = new Date(time);
  return (
    date.getDate() +
    " " +
    monthShortNames[date.getMonth()] +
    ", " +
    date.getFullYear()
  );
};
