import React from "react";
import { connect } from "react-redux";
import { BrowserRouter as Router, Route, Switch } from "react-router-dom";
import { compose } from "recompose";

import Navigation from "../../components/Navigation";
import Footer from "../../components/Footer";
import HomePage from "../Home";
import SignUpPage from "../SignUp";
import SignInPage from "../SignIn";
import PasswordForgetPage from "../PasswordForget";
import AccountPage from "../Account";
import NotFoundPage from "../NotFound";
import AboutPage from "../About";
import PrivacyPage from "../Privacy";
import TermsPage from "../Terms";
import PaymentForm from "../PaymentForm";
// import AdminPage from "../Admin";
import LotPage from "../Lot";

import * as ROUTES from "../../constants/routes";
import { withAuthentication } from "../../components/Session";
import { setAuthUserToken } from "../../actions/user";
import "../../utils/extenders";

import "./App.scss";
import "./range.scss";

// import IndexedDB from "../../utils/IndexedDB";
// const IDB = new IndexedDB();

class App extends React.Component {
  // componentWillUpdate(){
  //   const { setAuthUserToken } = this.props;
  //   IDB.getDB().then(db => {
  //     var transaction = db.transaction(["firebaseLocalStorage"]);
  //     var objectStore = transaction.objectStore("firebaseLocalStorage");
  //     var request = objectStore.get(`firebase:authUser:${process.env.REACT_APP_API_KEY}:[DEFAULT]`);
  //     request.onerror = event => {
  //       console.error("ERROR: GET TOKEN FROM IDB", event);
  //     };
  //     request.onsuccess = event => {
  //       console.log("IDB DATA", JSON.stringify(request.result.value, null, 2));
  //       const token = request.result.value.stsTokenManager.accessToken;
  //       setAuthUserToken(token);
  //     };
  //   }).catch(() => {
  //   });
  // }

  render() {
    const { activeRoute, authUser } = this.props;
    const showNav =
      activeRoute !== ROUTES.SIGN_IN &&
      activeRoute !== ROUTES.SIGN_UP &&
      activeRoute !== ROUTES.PAYMENT_FORM;

    return (
      <Router>
        {showNav && <Navigation current={activeRoute} user={authUser} />}
        <Switch>
          <Route path={ROUTES.SIGN_UP} component={SignUpPage} />
          <Route path={ROUTES.SIGN_IN} component={SignInPage} />
          <Route path={ROUTES.PASSWORD_FORGET} component={PasswordForgetPage} />
          <Route path={ROUTES.ACCOUNT} component={AccountPage} />
          <Route path={ROUTES.LOT} component={LotPage} />
          <Route exact path={ROUTES.HOME} component={HomePage} />
          <Route exact path={ROUTES.ABOUT} component={AboutPage} />
          <Route exact path={ROUTES.TERMS} component={TermsPage} />
          <Route exact path={ROUTES.PRIVACY} component={PrivacyPage} />
          <Route exact path={ROUTES.PAYMENT_FORM} component={PaymentForm} />
          {/* <Route path={ROUTES.ADMIN} component={AdminPage} /> */}
          <Route component={NotFoundPage} />
        </Switch>
        {showNav && <Footer current={activeRoute} user={authUser} />}
      </Router>
    );
  }
}

const mapStateToProps = state => ({
  authUser: state.session.authUser,
  activeRoute: state.page.activeRoute
});
const mapDispatchToProps = dispatch => ({
  setAuthUserToken: token => dispatch(setAuthUserToken(token))
});

export default compose(
  withAuthentication,
  connect(
    mapStateToProps,
    mapDispatchToProps
  )
)(App);
